@@ -185,8 +185,9 @@ parse_footnotes = function(x, fn_label = 'fn') {
     '<li id="%s([0-9]+)"><p>(.+)<a href="#%sref\\1"([^>]*)>.</a></p></li>',
     fn_label, fn_label
   )
+  s = paste(x[i:j], collapse = '\n')
   list(
-    items = gsub(r, '\\2', grep(r, x[i:n], value = TRUE)),
+    items = gsub(r, '\\2', unlist(regmatches(s, gregexpr(r, s)))),
     range = i:j
   )
 }
